create_instance

Function create_instance 

pub fn create_instance() -> Instance
Create a Vulkan instance. In debug mode, the Vulkan instance will have the validation layer enabled. In release mode, the Vulkan instance will not have the validation layer enabled. The instance is automatically destroyed when it goes out of scope. The instance is asserted to be valid with an assert!(!instance.is_null()) call. Will panic if the instance creation fails. Maps the vkCreateInstance function.